@@ -45,6 +45,9 @@ _FACADE = None
 def _create_facade_lazily():
     global _FACADE
     if _FACADE is None:
+        # FIXME(hongbin): we need to remove reliance on autocommit semantics
+        # ASAP since it's not compatible with SQLAlchemy 2.0
+        db_session.enginefacade.configure(__autocommit=True)
         _FACADE = db_session.enginefacade.get_legacy_facade()
         if profiler_sqlalchemy:
             if CONF.profiler.enabled and CONF.profiler.trace_sqlalchemy:
@@ -1195,7 +1198,8 @@ class Connection(object):
         return result
 
     def _add_networks_filters(self, query, filters):
-        filter_names = ['name', 'neutron_net_id', 'project_id', 'user_id']
+        filter_names = ['name', 'neutron_net_id', 'project_id', 'user_id',
+                        'host']
         return self._add_filters(query, models.Network, filters=filters,
                                  filter_names=filter_names)
 
